@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -34,6 +34,7 @@
 #include <openvdb/Exceptions.h>
 #include "Math.h"
 #include "Tuple.h"
+#include <algorithm>
 #include <cmath>
 #include <type_traits>
 
@@ -49,8 +50,8 @@ template<typename T>
 class Vec2: public Tuple<2, T>
 {
 public:
-    typedef T value_type;
-    typedef T ValueType;
+    using value_type = T;
+    using ValueType = T;
 
     /// Trivial constructor, the vector is NOT initialized
     Vec2() {}
@@ -273,7 +274,7 @@ public:
         return l2 ? *this/static_cast<T>(sqrt(l2)) : Vec2<T>(1,0);
     }
 
-    /// Returns v, where \f$v_i *= scalar\f$ for \f$i \in [0, 1]\f$
+    /// Multiply each element of this vector by @a scalar.
     template <typename S>
     const Vec2<T> &operator*=(S scalar)
     {
@@ -282,7 +283,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i *= v1_i\f$ for \f$i \in [0, 1]\f$
+    /// Multiply each element of this vector by the corresponding element of the given vector.
     template <typename S>
     const Vec2<T> &operator*=(const Vec2<S> &v1)
     {
@@ -291,7 +292,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i /= scalar\f$ for \f$i \in [0, 1]\f$
+    /// Divide each element of this vector by @a scalar.
     template <typename S>
     const Vec2<T> &operator/=(S scalar)
     {
@@ -300,7 +301,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i /= v1_i\f$ for \f$i \in [0, 1]\f$
+    /// Divide each element of this vector by the corresponding element of the given vector.
     template <typename S>
     const Vec2<T> &operator/=(const Vec2<S> &v1)
     {
@@ -309,7 +310,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i += scalar\f$ for \f$i \in [0, 1]\f$
+    /// Add @a scalar to each element of this vector.
     template <typename S>
     const Vec2<T> &operator+=(S scalar)
     {
@@ -318,7 +319,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i += v1_i\f$ for \f$i \in [0, 1]\f$
+    /// Add each element of the given vector to the corresponding element of this vector.
     template <typename S>
     const Vec2<T> &operator+=(const Vec2<S> &v1)
     {
@@ -327,7 +328,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i += scalar\f$ for \f$i \in [0, 1]\f$
+    /// Subtract @a scalar from each element of this vector.
     template <typename S>
     const Vec2<T> &operator-=(S scalar)
     {
@@ -336,7 +337,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i -= v1_i\f$ for \f$i \in [0, 1]\f$
+    /// Subtract each element of the given vector from the corresponding element of this vector.
     template <typename S>
     const Vec2<T> &operator-=(const Vec2<S> &v1)
     {
@@ -381,14 +382,14 @@ public:
 };
 
 
-/// Returns V, where \f$V_i = v_i * scalar\f$ for \f$i \in [0, 1]\f$
+/// Multiply each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec2<typename promote<S, T>::type> operator*(S scalar, const Vec2<T> &v)
 {
     return v * scalar;
 }
 
-/// Returns V, where \f$V_i = v_i * scalar\f$ for \f$i \in [0, 1]\f$
+/// Multiply each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec2<typename promote<S, T>::type> operator*(const Vec2<T> &v, S scalar)
 {
@@ -397,7 +398,7 @@ inline Vec2<typename promote<S, T>::type> operator*(const Vec2<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i * v1_i\f$ for \f$i \in [0, 1]\f$
+/// Multiply corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec2<typename promote<T0, T1>::type> operator*(const Vec2<T0> &v0, const Vec2<T1> &v1)
 {
@@ -405,14 +406,14 @@ inline Vec2<typename promote<T0, T1>::type> operator*(const Vec2<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = scalar / v_i\f$ for \f$i \in [0, 1]\f$
+/// Divide @a scalar by each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec2<typename promote<S, T>::type> operator/(S scalar, const Vec2<T> &v)
 {
     return Vec2<typename promote<S, T>::type>(scalar/v[0], scalar/v[1]);
 }
 
-/// Returns V, where \f$V_i = v_i / scalar\f$ for \f$i \in [0, 1]\f$
+/// Divide each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec2<typename promote<S, T>::type> operator/(const Vec2<T> &v, S scalar)
 {
@@ -421,7 +422,7 @@ inline Vec2<typename promote<S, T>::type> operator/(const Vec2<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i / v1_i\f$ for \f$i \in [0, 1]\f$
+/// Divide corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec2<typename promote<T0, T1>::type> operator/(const Vec2<T0> &v0, const Vec2<T1> &v1)
 {
@@ -429,7 +430,7 @@ inline Vec2<typename promote<T0, T1>::type> operator/(const Vec2<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i + v1_i\f$ for \f$i \in [0, 1]\f$
+/// Add corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec2<typename promote<T0, T1>::type> operator+(const Vec2<T0> &v0, const Vec2<T1> &v1)
 {
@@ -438,7 +439,7 @@ inline Vec2<typename promote<T0, T1>::type> operator+(const Vec2<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v_i + scalar\f$ for \f$i \in [0, 1]\f$
+/// Add @a scalar to each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec2<typename promote<S, T>::type> operator+(const Vec2<T> &v, S scalar)
 {
@@ -447,7 +448,7 @@ inline Vec2<typename promote<S, T>::type> operator+(const Vec2<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i - v1_i\f$ for \f$i \in [0, 1]\f$
+/// Subtract corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec2<typename promote<T0, T1>::type> operator-(const Vec2<T0> &v0, const Vec2<T1> &v1)
 {
@@ -456,7 +457,7 @@ inline Vec2<typename promote<T0, T1>::type> operator-(const Vec2<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v_i - scalar\f$ for \f$i \in [0, 1]\f$
+/// Subtract @a scalar from each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec2<typename promote<S, T>::type> operator-(const Vec2<T> &v, S scalar)
 {
@@ -552,10 +553,10 @@ inline Vec2<T> Exp(Vec2<T> v) { return v.exp(); }
 template <typename T>
 inline Vec2<T> Log(Vec2<T> v) { return v.log(); }
 
-typedef Vec2<int32_t>   Vec2i;
-typedef Vec2<uint32_t>  Vec2ui;
-typedef Vec2<float>     Vec2s;
-typedef Vec2<double>    Vec2d;
+using Vec2i = Vec2<int32_t>;
+using Vec2ui = Vec2<uint32_t>;
+using Vec2s = Vec2<float>;
+using Vec2d = Vec2<double>;
 
 } // namespace math
 } // namespace OPENVDB_VERSION_NAME
@@ -563,6 +564,6 @@ typedef Vec2<double>    Vec2d;
 
 #endif // OPENVDB_MATH_VEC2_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
