@@ -6,12 +6,12 @@ var indexSectionsWithContent =
   3: "abcdefgilmnopqrstuv",
   4: "abcdefghijklmnopqrstuvwxyz~",
   5: "abcdfghilmnoprstvwxyz",
-  6: "_abcdefghilmnopqrstuvw",
-  7: "abcdglmnrstv",
+  6: "_abcdefghilmnopqrstuvwxz",
+  7: "abcdfglmnrstv",
   8: "abcdefghilmnoprstuvwxyz",
-  9: ":bfilmoprstv",
-  10: "_beopuv",
-  11: "cfoprtu"
+  9: ":abcfilmoprstv",
+  10: "ceopuv",
+  11: "cdfoprtu"
 };
 
 var indexSectionNames =
